VesperDownloadTaskUpdatedEvent class final
- Inheritance
-
- Object
- VesperDownloadManagerEvent
- VesperDownloadTaskUpdatedEvent
Constructors
- VesperDownloadTaskUpdatedEvent({required String downloadId, VesperDownloadTaskSnapshot? task, VesperDownloadTaskStatePatch? patch, VesperDownloadTaskProgressPatch? progressPatch})
-
const
Properties
- downloadId → String
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- patch → VesperDownloadTaskStatePatch?
-
final
- progressPatch → VesperDownloadTaskProgressPatch?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- task → VesperDownloadTaskSnapshot?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited