VesperFrameProcessorConfiguration class final
Constructors
-
VesperFrameProcessorConfiguration({VesperFrameProcessorMode mode = VesperFrameProcessorMode.disabled, List<
VesperPluginReference> pluginReferences = const <VesperPluginReference>[]}) -
const
-
VesperFrameProcessorConfiguration.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasOverrides → bool
-
no setter
- mode → VesperFrameProcessorMode
-
final
-
pluginReferences
→ List<
VesperPluginReference> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited