VesperHdrOutputFormat enum
The observed output format, when the platform can identify it independently of the source format. Confirmed HDR may still have an unknown format.
Values
- unknown → const VesperHdrOutputFormat
- hdr10 → const VesperHdrOutputFormat
- hlg → const VesperHdrOutputFormat
- dolbyVision → const VesperHdrOutputFormat
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VesperHdrOutputFormat> - A constant List of the values in this enum, in order of their declaration.