VesperItemsRequested class final

Constructors

VesperItemsRequested({required String sequenceId, required int sessionGeneration, required int requestId, required VesperPlaybackSequenceDirection direction, required String? anchorItemId, required int maxCount, required int deadline})
const
VesperItemsRequested.fromMap(Map<Object?, Object?> map)
factory

Properties

anchorItemId String?
final
deadline int
final
direction VesperPlaybackSequenceDirection
final
hashCode int
The hash code for this object.
no setterinherited
maxCount int
final
requestId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceId String
final
sessionGeneration int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited