VesperPictureInPictureAvailability class final

Constructors

VesperPictureInPictureAvailability({required bool isAvailable, bool isActive = false, bool canAutoEnter = false, String source = 'system', VesperPictureInPictureError? error, Map<String, Object?> diagnostics = const <String, Object?>{}})
const
VesperPictureInPictureAvailability.fromMap(Map<Object?, Object?> map)
factory

Properties

canAutoEnter bool
final
diagnostics Map<String, Object?>
final
error VesperPictureInPictureError?
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool
final
isAvailable bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited