VesperPictureInPictureError class final
Constructors
-
VesperPictureInPictureError({required VesperPictureInPictureErrorCode code, String message = 'Current playback cannot enter Picture in Picture.', String userMessage = 'Current playback cannot enter Picture in Picture.', Map<
String, Object?> diagnostics = const <String, Object?>{}}) -
const
-
VesperPictureInPictureError.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- code → VesperPictureInPictureErrorCode
-
final
-
diagnostics
→ Map<
String, Object?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userMessage → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited