VesperPlatformDownloadCreateResult class final

Constructors

VesperPlatformDownloadCreateResult({required String downloadId, required VesperDownloadSnapshot snapshot})
const
VesperPlatformDownloadCreateResult.fromMap(Map<Object?, Object?> map)
factory

Properties

downloadId String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot VesperDownloadSnapshot
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited