VesperPlaybackSequenceItemsRequestedEvent class final

Inheritance

Constructors

VesperPlaybackSequenceItemsRequestedEvent({required String sequenceId, required int sessionGeneration, required VesperItemsRequested request})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
request VesperItemsRequested
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceId String
finalinherited
sessionGeneration int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited