VesperPlaybackSequencePreloadProfile class final

Constructors

VesperPlaybackSequencePreloadProfile({int expectedMemoryBytes = 0, int expectedDiskBytes = 0, int? ttlMs, int? warmupWindowMs})
const

Properties

expectedDiskBytes int
final
expectedMemoryBytes int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttlMs int?
final
warmupWindowMs int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited