VesperPlayerUnknownEvent class final

Inheritance

Constructors

VesperPlayerUnknownEvent({required String playerId, required String type, Map<String, Object?> payload = const <String, Object?>{}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
payload Map<String, Object?>
final
playerId String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited