VesperPlayerWarningEvent class final
- Inheritance
-
- Object
- VesperPlayerEvent
- VesperPlayerWarningEvent
Constructors
- VesperPlayerWarningEvent({required String playerId, required VesperRuntimeWarning warning})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- playerId → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warning → VesperRuntimeWarning
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited