VesperSystemPlaybackMetadata class final

Constructors

VesperSystemPlaybackMetadata({required String title, String? artist, String? albumTitle, String? artworkUri, String? contentUri, int? durationMs, bool isLive = false})
const
VesperSystemPlaybackMetadata.fromMap(Map<Object?, Object?> map)
factory

Properties

albumTitle String?
final
artist String?
final
artworkUri String?
final
contentUri String?
final
durationMs int?
final
hashCode int
The hash code for this object.
no setterinherited
isLive bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited