VesperTimeline class final

Constructors

VesperTimeline({required VesperTimelineKind kind, required bool isSeekable, required int positionMs, VesperSeekableRange? seekableRange, int? liveEdgeMs, int? durationMs})
const
VesperTimeline.fromMap(Map<Object?, Object?> map)
factory
VesperTimeline.fromSampleMap(Map<Object?, Object?> map)
Decodes a timeline returned by the timeline-only platform operation.
factory
VesperTimeline.initial()
const

Properties

displayedRatio double?
no setter
durationMs int?
final
goLivePositionMs int?
no setter
hashCode int
The hash code for this object.
no setterinherited
isSeekable bool
final
kind VesperTimelineKind
final
liveEdgeMs int?
final
liveOffsetMs int?
no setter
positionMs int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seekableRange VesperSeekableRange?
final

Methods

clampedPosition(int positionMs) int
isAtLiveEdge({int toleranceMs = 1500}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionForRatio(double ratio) int
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited