VesperDownloadConfiguration class final
Constructors
-
VesperDownloadConfiguration({bool autoStart = true, bool runPostProcessorsOnCompletion = true, bool resumePartialDownloads = true, bool restoreTasksOnStartup = true, String? baseDirectory, List<
VesperPluginReference> postDownloadPluginReferences = const <VesperPluginReference>[], List<VesperPluginReference> eventHookPluginReferences = const <VesperPluginReference>[], int? rangeChunkBytes, int minProgressBytes = 512 * 1024, int minProgressIntervalMs = 250}) -
const
-
VesperDownloadConfiguration.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- autoStart → bool
-
final
- baseDirectory → String?
-
final
-
eventHookPluginReferences
→ List<
VesperPluginReference> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- minProgressBytes → int
-
final
- minProgressIntervalMs → int
-
final
-
postDownloadPluginReferences
→ List<
VesperPluginReference> -
final
- rangeChunkBytes → int?
-
final
- restoreTasksOnStartup → bool
-
final
- resumePartialDownloads → bool
-
final
- runPostProcessorsOnCompletion → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited