VesperNativeFramePipelineConfiguration class final
Constructors
-
VesperNativeFramePipelineConfiguration({VesperNativeFramePipelineMode mode = VesperNativeFramePipelineMode.disabled, List<
VesperPluginReference> decoderPluginReferences = const <VesperPluginReference>[], List<VesperPluginReference> frameProcessorPluginReferences = const <VesperPluginReference>[], int? maxInFlightFrames}) -
const
-
VesperNativeFramePipelineConfiguration.fromMap(Map<
Object?, Object?> map) -
factory
Properties
-
decoderPluginReferences
→ List<
VesperPluginReference> -
final
-
frameProcessorPluginReferences
→ List<
VesperPluginReference> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasOverrides → bool
-
no setter
- maxInFlightFrames → int?
-
final
- mode → VesperNativeFramePipelineMode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited