VesperPerformanceOverlayState class final
Constructors
- VesperPerformanceOverlayState({required bool active, VesperPerformanceSampleClass sampleClass = VesperPerformanceSampleClass.steady, int? loadedBasicItemCount, int? loadedAdvancedItemCount, bool advancedEffectsActive = false})
-
const
-
VesperPerformanceOverlayState.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- active → bool
-
final
- advancedEffectsActive → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadedAdvancedItemCount → int?
-
final
- loadedBasicItemCount → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleClass → VesperPerformanceSampleClass
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited