VesperPipelineEventHookError class final
Constructors
- VesperPipelineEventHookError({required VesperPipelineEventHookErrorCode code, required String message, String? codeRawValue})
-
const
-
VesperPipelineEventHookError.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- code → VesperPipelineEventHookErrorCode
-
final
- codeRawValue → String?
-
final
- codeWireValue → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited