VesperPlaybackSequenceConfiguration class final
Constructors
- VesperPlaybackSequenceConfiguration({required String sequenceId, VesperPlaybackSequenceMode mode = VesperPlaybackSequenceMode.finite, int historyLimit = 16, int forwardWindow = 1, int refillThreshold = 1, int maxItems = 512, int maxPendingRequests = 32, int maxEvents = 512, int requestTimeoutMs = 15000, int sourceExpiryLeadMs = 15000, int maxSourceRegistryEntries = 1024})
-
const
Properties
- forwardWindow → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- historyLimit → int
-
final
- maxEvents → int
-
final
- maxItems → int
-
final
- maxPendingRequests → int
-
final
- maxSourceRegistryEntries → int
-
final
- mode → VesperPlaybackSequenceMode
-
final
- refillThreshold → int
-
final
- requestTimeoutMs → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequenceId → String
-
final
- sourceExpiryLeadMs → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited