VesperSystemPlaybackConfiguration class final
Constructors
- VesperSystemPlaybackConfiguration({bool enabled = true, VesperBackgroundPlaybackMode backgroundMode = VesperBackgroundPlaybackMode.continueAudio, bool showSystemControls = true, bool showSeekActions = true, VesperSystemPlaybackMetadata? metadata, VesperSystemPlaybackControls? controls})
-
const
-
VesperSystemPlaybackConfiguration.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- backgroundMode → VesperBackgroundPlaybackMode
-
final
- controls → VesperSystemPlaybackControls?
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata → VesperSystemPlaybackMetadata?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showSeekActions → bool
-
final
- showSystemControls → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited